/**
 * This file combines all default css files. It will be parsed by the build
 * processor to generate a minified geoext-all.css file. Theme specific
 * overrides go into gxtheme-<theme>.css
 */
@import "popup.css";
@import "layerlegend.css";
@import "symbolizercolumn.css";
