body {
    font-family: tahoma,arial,helvetica,sans-serif;
    font-size: 10px;
    background-color: white;
}

h2 {
    text-align: center;
    font-weight: bold;
    font-size: 12px;
}

div.versioninfo {
    text-align: center;
}

div.logo {
    margin-left: auto;
    margin-right: auto;
    width: 100%;
    text-align: center;
    height: 70px;
    background: url('img/GeoExt_Logo.png') center no-repeat;
}

h3 {
    font-weight: bold;
    margin-bottom: 0em;
    font-size: 12px;
}

a {
    display: block;
}

