/* setting font fixes combobox rendering issues in IE. See
 * http://extjs.com/forum/showthread.php?t=72505 */
body {
    font-family:helvetica,tahoma,verdana,sans-serif;
}

/* get images on buttons with text to line up with those with no text */
.x-btn-text-icon .x-btn-center .x-btn-text {
    background-position: 0 3px;
}

/* apply some margin when using the row expander */
.x-grid3-row-body p {
    margin: 5px !important;
}

/* workaround for semi-alpha pixels in IE7: background needs to be the same
 * as the toolbar's background color */
.ext-ie .x-item-disabled .x-btn-text {
    background-color: #EAEAEA;
}

.x-tree-node img.gx-folder, .x-tree-node-collapsed img.gx-folder{
    background: url(../../externals/ext/resources/images/default/tree/folder.gif);
}
 
.x-tree-node-expanded img.gx-folder {
    background: url(../../externals/ext/resources/images/default/tree/folder-open.gif);
}

.x-btn .login {
    background-image: url(img/silk/door_in.png);
}

.x-btn .logout {
    background-image: url(img/silk/door_out.png);
}

.x-btn .icon-geoexplorer {
    background-image: url(img/geoexplorer.png);
}

.x-btn .icon-about {
    background-image: url(img/silk/help.png);
}

.x-btn .icon-addlayers {
    background-image: url(img/silk/add.png);
}

.x-btn .icon-addserver {
    background-image: url(img/silk/map_add.png);
}

.x-btn .icon-removelayers, .x-menu-item .icon-removelayers {
    background-image: url(img/silk/delete.png);
}

.x-btn .icon-properties, .x-menu-item .icon-properties {
    background-image: url(img/silk/wrench.png);
}

.x-btn .icon-getfeatureinfo {
    background-image: url(img/silk/information.png);
}

.x-btn .icon-map {
    background-image: url(img/silk/map.png);
}
.x-btn .icon-save, .x-menu-item .icon-save {
    background-image: url(img/geosilk/map_save.png);
}
.x-btn .icon-export, .x-menu-item .icon-export {
    background-image: url(img/silk/map_go.png);
}

.x-btn .icon-measure {
    background-image: url(img/geosilk/measure.png);
}

.icon-measure-length {
    background-image: url(img/geosilk/ruler.png) !important;
}

.icon-measure-area {
   background-image: url(img/geosilk/ruler_square.png) !important;
}

.x-btn .icon-layer-switcher {
   background-image: url(img/silk/layers.png);
}

.x-btn .icon-zoom-in { 
    background-image: url(img/silk/magnifier_zoom_in.png);
}

.x-btn .icon-zoom-out { 
    background-image: url(img/silk/magnifier_zoom_out.png);
}

.x-btn .icon-zoom-previous { 
    background-image: url(img/silk/arrow_left.png);
}

.x-btn .icon-zoom-next { 
    background-image: url(img/silk/arrow_right.png);
}

.x-btn .icon-zoom-visible { 
    background-image: url(img/silk/arrow_out.png);
}

.x-btn .icon-zoom-to, .x-menu-item .icon-zoom-to { 
    background-image: url(img/silk/magnifier.png);
}

.x-btn .icon-pan { 
    background-image: url(img/geosilk/pan.png);
}

.x-btn .icon-3D {
    background-image: url(img/geosilk/google_earth.png);
}

/* Pan- and Zoom- Panel Styles*/

.olControlPanPanel div {
    background-image:url(../../externals/ext/resources/images/gray/panel/tool-sprites.gif);
    height:15px;
    width:15px;
    /* workaround for button height in IE */
    font-size:0px;
}

.olControlPanPanel .olControlPanNorthItemInactive {
    background-position:15px -60px;
    left:16px
}
.olControlPanPanel .olControlPanEastItemInactive {
    background-position:15px -120px;
    left: 30px;
    top: 16px;
}
.olControlPanPanel .olControlPanSouthItemInactive {
    background-position:15px -75px;
    left: 16px;
    top: 32px;
}
.olControlPanPanel .olControlPanWestItemInactive {
    background-position:15px -105px;
    left: 2px;
    top: 16px;
}

.olControlZoomPanel { 
    left:21px;
}

.olControlZoomPanel div {
    background-image:url(../../externals/ext/resources/images/gray/panel/tool-sprites.gif);
    height:15px;
    width:15px;
    /* workaround for button height in IE */
    font-size:0px;
}

.olControlZoomPanel .olControlZoomInItemInactive {
    background-position:15px -240px;
}

.olControlZoomPanel .olControlZoomToMaxExtentItemInactive {
    display: none;
}

.olControlZoomPanel .olControlZoomOutItemInactive {
    background-position:15px -255px;
    top: 123px;
}

.olControlScaleLine {
    font-family: tahoma,arial,helvetica,sans-serif;
}

.olControlAttribution {
    bottom: 5px;
    font-size: 10px;
    left: 10px;
    right: inherit;
}

/* position the zoom slider within map panel */
.gx-zoomslider {
    top: 90px;
    left: 17px
}

.gx-layer-visibility {
    background-image: url(img/silk/eye.png);
}

.gx-field-label {
    font-weight: bold;
    margin: 4px;
    vertical-align: baseline;
}

.gx-export-section {
    padding: 10px 10px 5px 10px;
}

.gx-info-panel {
    margin: 1em;
}

/* Color Picker tweaks */
div.x-cp-coloro-container {
    margin: 4px 0 5px 0;
}
.x-cp-rgb-container div.x-panel-mc {
    padding-top: 0;
}
.x-cp-rgb-container .x-form-item label.x-form-item-label {
    padding-top: 1px;
}

.gx-info-panel h2 {
    margin-top: 1em;
}

/* TODO: Remove this if GetFeatureInfo is changed from text/html */

table.featureInfo, table.featureInfo td, table.featureInfo th {
    border: 1px solid #ddd;
    border-collapse: collapse;
    margin: 0;
    padding: 0;
    font-size: 90%;
    padding: .2em .1em;
}
table.featureInfo th {
    padding: .2em .2em;
    font-weight: bold;
    background: #eee;
}
table.featureInfo td{
    background: #fff;
}
table.featureInfo tr.odd td{
    background: #eee;
}
table.featureInfo caption{
    text-align: left;
    font-size: 100%;
    font-weight: bold;
    text-transform: uppercase;
    padding: .2em .2em;
}

