.gx-popup-anc {
    background: transparent url(../images/default/anchor.png) no-repeat 0 0;
    position: absolute;
    left: 5px;
    z-index: 2;
    height: 16px;
    width: 31px;
    pointer-events: none;
}

.gx-popup-anc.top {
    background: transparent url(../images/default/anchor-top.png) no-repeat 0 0;
    top: -16px; /* height(gx-popup-anc) */
}

.gx-popup-anc.right {
    left: auto;
    right: 5px;
}
